Partially revert "nasm defaults to -Ox"

The -Ox check in still useful to avoid the version of nasm distributed
with Apple Xcode.

This reverts commit 29b0c186ec421f879ee5e9193238065ce9bd477b.

Change-Id: I9237791802267da708c3be8e5a83ca8d71e74afc
diff --git a/build/cmake/aom_optimization.cmake b/build/cmake/aom_optimization.cmake
index 59b47e8..c58c399 100644
--- a/build/cmake/aom_optimization.cmake
+++ b/build/cmake/aom_optimization.cmake
@@ -200,11 +200,17 @@
 endfunction ()
 
 # Terminates generation if nasm found in PATH does not meet requirements.
 # Currently checks only for presence of required object formats.
 function (test_nasm)
   execute_process(COMMAND ${AS_EXECUTABLE} -hf
                   OUTPUT_VARIABLE nasm_helptext)
 
+  if (NOT "${nasm_helptext}" MATCHES "-Ox")
+    message(FATAL_ERROR
+            "Unsupported nasm: multipass optimization not supported.")
+  endif ()
+
   if ("${AOM_TARGET_CPU}" STREQUAL "x86")
     if ("${AOM_TARGET_SYSTEM}" STREQUAL "Darwin")
       if (NOT "${nasm_helptext}" MATCHES "macho32")
@@ -200,11 +200,17 @@
 
 # Terminates generation if nasm found in PATH does not meet requirements.
-# Currently checks only for presence of required object formats.
+# Currently checks only for presence of required object formats and support for
+# the -Ox argument (multipass optimization).
 function (test_nasm)
   execute_process(COMMAND ${AS_EXECUTABLE} -hf